.. role:: hidden
    :class: hidden-section

ax.api
==========

.. automodule:: ax.preview
.. currentmodule:: ax.preview

The Ax API
--------------------------


IMetric
~~~~~~~

.. automodule:: ax.api.protocols.metric
    :members:
    :undoc-members:
    :show-inheritance:

IRunner
~~~~~~~

.. automodule:: ax.api.protocols.runner
    :members:
    :undoc-members:
    :show-inheritance:


Client
~~~~~~

.. automodule:: ax.api.client
    :members:
    :undoc-members:
    :show-inheritance:


Configs
~~~~~~~

.. automodule:: ax.api.configs
    :members:
    :undoc-members:
    :show-inheritance:

Types
~~~~~

.. automodule:: ax.api.types
    :members:
    :undoc-members:
    :show-inheritance:

From Config
~~~~~~~~~~~

.. automodule:: ax.api.utils.instantiation.from_config
    :members:
    :undoc-members:
    :show-inheritance:
